==> git-open-1.0.8.tar.gz: git-open-1.0.8/README.md <==
# git-open

[![CI Status](https://travis-ci.com/cfarvidson/git-open.svg?branch=master)](https://travis-ci.com/cfarvidson/git-open)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![Maintainability](https://api.codeclimate.com/v1/badges/09be50f0293cfed0e89a/maintainability)](https://codeclimate.com/github/cfarvidson/git-open/maintainability)
[![Known Vulnerabilities](https://snyk.io/test/github/cfarvidson/git-open/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/cfarvidson/git-open?targetFile=requirements.txt)
[![Downloads](http://pepy.tech/badge/git-open)](http://pepy.tech/project/git-open)

Open a git repo in the browser from the terminal.

## Features

From the terminal type the following command to open the current repository in your browser.

```
git open
```

or

```
git-open
```

## Installation

### Using pip

    pip install git-open

### Using pipsi (recommended)

[pipsi](https://github.com/mitsuhiko/pipsi) is a great tool to install python tools globally.

> pipsi makes installing python packages with global entry points painless.
> These are Python packages that expose an entry point through the command line such as Pygments.

    pipsi install git-open

## Credits

This package was initially created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.

## License

GNU General Public License v3.0

See [LICENSE](LICENSE) to see the full text.

==> git-open-1.1.0.tar.gz: git-open-1.1.0/README.md <==
# git-open

[![CI Status](https://travis-ci.com/cfarvidson/git-open.svg?branch=master)](https://travis-ci.com/cfarvidson/git-open)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![Maintainability](https://api.codeclimate.com/v1/badges/09be50f0293cfed0e89a/maintainability)](https://codeclimate.com/github/cfarvidson/git-open/maintainability)
[![Downloads](http://pepy.tech/badge/git-open)](http://pepy.tech/project/git-open)

Open a git repo in the browser from the terminal.

## Features

From the terminal type the following command to open the current repository in your browser.

### Usage

```
$ git-open --help
Usage: git-open [OPTIONS] COMMAND [ARGS]...

  Open a git repo in the browser from the terminal.

  Running the command without any sub-command will open the main page of the
  repository.

Options:
  --help  Show this message and exit.

Commands:
  branch   Open the current branch
  commit   Open the current commit
  version  Show the current git-open version
```

## Installation

### Using pip

    pip install git-open

### Using pipx (recommended)

[pipx](https://github.com/pipxproject/pipx) is a great tool to install python tools globally.

Installing pipx on macOS:

    brew install pipx
    pipx ensurepath

Installing git-open using pipx:

    pipx install git-open

## Credits

This package was initially created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.

## License

GNU General Public License v3.0

See [LICENSE](LICENSE) to see the full text.
